summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/texteffect/texteffectpreferences.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/texteffect/texteffectpreferences.cpp')
-rw-r--r--kopete/plugins/texteffect/texteffectpreferences.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/plugins/texteffect/texteffectpreferences.cpp b/kopete/plugins/texteffect/texteffectpreferences.cpp
index ddbe5f61..d2584328 100644
--- a/kopete/plugins/texteffect/texteffectpreferences.cpp
+++ b/kopete/plugins/texteffect/texteffectpreferences.cpp
@@ -35,10 +35,10 @@
typedef KGenericFactory<TextEffectPreferences> TextEffectPreferencesFactory;
K_EXPORT_COMPONENT_FACTORY( kcm_kopete_texteffect, TextEffectPreferencesFactory( "kcm_kopete_texteffect" ) )
-TextEffectPreferences::TextEffectPreferences(TQWidget *tqparent,
+TextEffectPreferences::TextEffectPreferences(TQWidget *parent,
const char* /*name*/,
const TQStringList &args)
- : KCModule(TextEffectPreferencesFactory::instance(), tqparent, args)
+ : KCModule(TextEffectPreferencesFactory::instance(), parent, args)
{
( new TQVBoxLayout( this ) )->setAutoAdd( true );
@@ -106,7 +106,7 @@ void TextEffectPreferences::load()
preferencesDialog->m_casewaves->setChecked(config->waves());
// Call tqparent's save method
KCModule::load();
// Indicate that we have not changed ^_^
@@ -134,7 +134,7 @@ void TextEffectPreferences::save()
// Notify the plugin that the settings have changed
//TextEffectPlugin::plugin()->slotSettingsChanged();
// Call tqparent's save method
KCModule::save();
// Indicate that we have not changed ^_^
@@ -106,7 +106,7 @@ void TextEffectPreferences::load()
preferencesDialog->m_casewaves->setChecked(config->waves());
- // Call tqparent's save method
+ // Call parent's save method
KCModule::load();
// Indicate that we have not changed ^_^
@@ -134,7 +134,7 @@ void TextEffectPreferences::save()
// Notify the plugin that the settings have changed
//TextEffectPlugin::plugin()->slotSettingsChanged();
- // Call tqparent's save method
+ // Call parent's save method
KCModule::save();
// Indicate that we have not changed ^_^